@@ -34,8 +34,9 @@ import warnings
 import numpy as np
 
 from NuMPI import MPI
+from NuMPI.Tools import Reduction
 
-from .Support import DeprecatedDictionary
+from .Support import doi, DeprecatedDictionary
 
 # Standardized entries for the info dictionary
 
@@ -98,9 +99,6 @@ class AbstractTopography(object):
     def __dir__(self):
         return sorted(super().__dir__() + [*self._functions])
 
-    def __eq__(self, other):
-        return self.unit == other.unit and self.info == other.info and self.is_periodic == other.is_periodic
-
     def __getstate__(self):
         """
         Upon pickling, it is called and the returned object is pickled as the
@@ -231,7 +229,12 @@ class DecoratedTopography(AbstractTopography):
 class TopographyInterface(object):
     @classmethod
     def register_function(cls, name, function):
-        cls._functions.update({name: function})
+        if function.__name__ != 'func_with_doi':
+            # We want the `dois` argument for all pipeline functions. If no
+            # doi has been specified, we simply wrap it in an empty decorator.
+            cls._functions.update({name: doi()(function)})
+        else:
+            cls._functions.update({name: function})
 
 
 class UniformTopographyInterface(TopographyInterface, metaclass=abc.ABCMeta):
@@ -309,7 +312,9 @@ class UniformTopographyInterface(TopographyInterface, metaclass=abc.ABCMeta):
             return p, h
 
     def __eq__(self, other):
-        return super.__eq__(self, other) and np.allclose(self.positions_and_heights(), other.positions_and_heights())
+        return Reduction(self._communicator).all(
+            self.unit == other.unit and self.info == other.info and self.is_periodic == other.is_periodic and
+            np.allclose(self.positions(), other.positions()) and np.allclose(self.heights(), other.heights()))
 
     def __getitem__(self, i):
         return self.heights()[i]
@@ -361,8 +366,14 @@ class NonuniformLineScanInterface(TopographyInterface, metaclass=abc.ABCMeta):
     def is_MPI(self):
         return False
 
+    @property
+    def has_undefined_data(self):
+        return False
+
     def __eq__(self, other):
-        return super.__eq__(self, other) and np.allclose(self.positions_and_heights(), other.positions_and_heights())
+        return Reduction(self._communicator).all(
+            self.unit == other.unit and self.info == other.info and self.is_periodic == other.is_periodic and
+            np.allclose(self.positions_and_heights(), other.positions_and_heights()))
 
     def __getitem__(self, i):
         return self.positions()[i], self.heights()[i]
