@@ -30,10 +30,8 @@ SurfaceTopography profile from file input
 """
 
 import xml.etree.ElementTree as ElementTree
-from struct import unpack
 from zipfile import ZipFile
 import numpy as np
-import numpy.ma as ma
 
 from .common import CHANNEL_NAME_INFO_KEY
 from .Reader import ReaderBase, ChannelInfo
@@ -59,23 +57,6 @@ def binary(func):
     return func_wrapper
 
 
-def mask_undefined(data, maxval=1e32):
-    """
-    If data contains undefined points, then return a masked array with all
-    undefined points masked.
-
-    The following heuristics is applied to identify undefined points:
-    - Remove points that are +/-inf or nan
-    - Remove points that are >+maxval or <-maxval
-    """
-    # First, we mask all points that are infinite or nan
-    mask = np.logical_and(np.isfinite(data), np.abs(data) < maxval)
-    if mask.sum() < len(mask):
-        return ma.masked_array(data, mask=np.logical_not(mask))
-    else:
-        return data
-
-
 def make_wrapped_reader(reader_func, class_name='WrappedReader', format=None,
                         name=None, description=None):
     class WrappedReader(ReaderBase):
@@ -248,107 +229,6 @@ data. The full specification of the format can be found
 ''')
 
 
-@binary
-def read_opd(fobj, physical_sizes=None, height_scale_factor=None, unit=None, info={},
-             periodic=False):
-    """
-    Load Wyko Vision OPD file.
-
-    FIXME: Descriptive error messages. Probably needs to be made more robust.
-
-    Keyword Arguments:
-    fobj -- filename or file object
-    """
-
-    if unit is not None:
-        raise MetadataAlreadyFixedByFile('unit')
-
-    BLOCK_SIZE = 24
-
-    def read_block(fobj):
-        blkname = fobj.read(16).split(b'\0', 1)[0].decode('latin-1')
-        blktype, blklen, blkattr = unpack('<hlH', fobj.read(8))
-        return blkname, blktype, blklen, blkattr
-
-    # Skip header
-    fobj.read(2)
-
-    # Read directory block
-    dirname, dirtype, dirlen, dirattr = read_block(fobj)
-    if dirname != 'Directory':
-        raise IOError("Error reading directory block. "
-                      "Header is '{}', expected 'Directory'".format(dirname))
-    num_blocks = dirlen // BLOCK_SIZE
-    if num_blocks * BLOCK_SIZE != dirlen:
-        raise IOError(
-            'Directory length is not a multiple of the block physical_sizes.')
-
-    blocks = []
-    for i in range(num_blocks - 1):
-        blocks += [read_block(fobj)]
-
-    data = None
-    nx = None
-    ny = None
-    pixel_size = 1.0
-    aspect = 1.0
-    mult = 1.0
-    for n, t, L, a in blocks:
-        if L <= 0:
-            continue
-        if n == 'RAW DATA' or n == 'RAW_DATA' or n == 'OPD' or n == 'Raw':
-            if data is not None:
-                raise IOError('Multiple data blocks encountered.')
-
-            nx, ny, elsize = unpack('<HHH', fobj.read(6))
-            if elsize == 1:
-                dtype = np.dtype('c')
-            elif elsize == 2:
-                dtype = np.dtype('<i2')
-            elif elsize == 4:
-                dtype = np.dtype('f4')
-            else:
-                raise IOError("Don't know how to handle element of size {}."
-                              .format(elsize))
-            rawdata = fobj.read(nx * ny * dtype.itemsize)
-            data = np.frombuffer(rawdata, count=nx * ny, dtype=dtype)
-        elif n == 'Wavelength':
-            wavelength, = unpack('<f', fobj.read(4))
-        elif n == 'Mult':
-            mult, = unpack('<H', fobj.read(2))
-        elif n == 'Aspect':
-            aspect, = unpack('<f', fobj.read(4))
-        elif n == 'Pixel_size':
-            pixel_size, = unpack('<f', fobj.read(4))
-        else:
-            fobj.read(L)
-
-    if data is None:
-        raise IOError('No data block encountered.')
-
-    data = mask_undefined(data)
-    data.shape = (nx, ny)
-
-    # Height are in nm, width in mm
-    if physical_sizes is not None:
-        raise MetadataAlreadyFixedByFile('physical_sizes')
-    surface = Topography(np.fliplr(data),
-                         (nx * pixel_size, ny * pixel_size * aspect),
-                         unit='mm', info=info, periodic=periodic)
-    height_scale_factor_from_file = wavelength / mult * 1e-6
-    if height_scale_factor is not None:
-        raise MetadataAlreadyFixedByFile('height_scale_factor')
-    surface = surface.scale(height_scale_factor_from_file)
-    return surface
-
-
-OPDReader = make_wrapped_reader(read_opd, class_name="OPDReader", format='opd',
-                                name='Wyko OPD', description='''
-Files generated by the Vision software of the Bruker Wyko white-light
-interferometer.
-''')
-
-
 @binary
 def read_hgt(fobj, physical_sizes=None, height_scale_factor=None, unit=None, info={},
              periodic=False):
