@@ -81,7 +81,10 @@ class ChannelInfo:
         self._height_scale_factor = height_scale_factor
         self._periodic = periodic
         self._unit = unit
-        self._info = info.copy()
+        if info is None:
+            self._info = None
+        else:
+            self._info = info.copy()
 
     def topography(self, physical_sizes=None, height_scale_factor=None, unit=None, info={}, periodic=False,
                    subdomain_locations=None, nb_subdomain_grid_pts=None):
@@ -176,6 +179,10 @@ class ChannelInfo:
         """
         return self._physical_sizes
 
+    @physical_sizes.setter
+    def physical_sizes(self, value):
+        self._physical_sizes = value
+
     @property
     def height_scale_factor(self):
         """
@@ -191,6 +198,10 @@ class ChannelInfo:
         """
         return self._height_scale_factor
 
+    @height_scale_factor.setter
+    def height_scale_factor(self, value):
+        self._height_scale_factor = value
+
     @property
     def is_periodic(self):
         """
